@@ -6,18 +6,10 @@
 		<string>BUNDLE_ID_PREFIX.privileged_startx</string>
 	<key>ProgramArguments</key>
 		<array>
-			<string>XINITDIR/privileged_startx</string>
+			<string>__libexecdir__/privileged_startx</string>
 			<string>-d</string>
 			<string>SCRIPTDIR</string>
 		</array>
-#ifdef TIGER_LAUNCHD
-	<key>RunAtLoad</key>
-		<true/>
-	<key>KeepAlive</key>
-		<true/>
-	<key>ServiceIPC</key>
-		<true/>
-#else
 	<key>MachServices</key>
 		<dict>
 			<key>BUNDLE_ID_PREFIX.privileged_startx</key>
@@ -27,6 +19,5 @@
 		<integer>120</integer>
 	<key>EnableTransactions</key>
 		<true/>
-#endif
 </dict>
 </plist>
